require 'thor'
require 'encrypted_yaml/configurator'
require 'encrypted_yaml/cli/encrypt'

module EncryptedYaml::CLI
  class CLI < Thor
    desc 'encrypt YAMLFILE', 'Encrypts the given yaml file with the keys available in the current directory. The keys do not exist, they will be auto-generated.'
    option :key, :default => "key"
    option :iv, :default => "iv"
    def encrypt(filename)
      raise "File does not exist" unless File.exists? filename

      enc_options = {
        filename: filename,
        keyfile: options[:key],
        ivfile: options[:iv]
      }
      encrypter = EncryptedYaml::CLI::Encrypt.new enc_options
      encrypted_copy = encrypter.encrypt
      
      new_filename = "#{filename}.enc"
      File.open(new_filename, 'wb') { |f| f.write encrypted_copy }
    end
  
    desc 'decrypt YAMLFILE', 'Decrypts the given yaml file with the keys available in the current directory.'
    option :key
    option :iv
    def decrypt(filename)
      raise "File does not exist" unless File.exists? filename
      
      decrypt_options = {
        keyfile: options[:key],
        ivfile: options[:iv]
      }
      
      conf = EncryptedYaml::Configurator.new filename, decrypt_options
      puts conf
    end
  end
end