require 'openssl'

module EncryptedYaml
  module CLI
    class Encrypt
      def initialize(options)
        @keyfile = options[:keyfile]
        @ivfile = options[:ivfile]
        @filename = options[:filename]
      end

      def encrypt
        data = File.read(@filename)

        cipher = get_cipher
        cipher.update(data) + cipher.final
      end

      private

      def get_cipher
        cipher = OpenSSL::Cipher::AES256.new :CBC
        cipher.encrypt
        set_key cipher
        set_iv cipher

        cipher
      end
      
      def set_key(cipher)
        if File.exists? @keyfile
          cipher.key = File.read(@keyfile)
          return
        end

        key = cipher.random_key
        File.open(@keyfile, 'wb') { |f| f.write key }
      end

      def set_iv(cipher)
        if File.exists? @ivfile
          cipher.iv = File.read(@ivfile)
          return
        end

        iv = cipher.random_iv
        File.open(@ivfile, 'wb') { |f| f.write iv }
      end
    end
  end
end